==> field_manager_python_client-4.4.82rc3.tar.gz: field_manager_python_client-4.4.82rc3/field-manager-python-client/api/locations/get_files_in_location_in_project_projects_project_id_locations_location_id_files_get.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.file import File
from ...models.file_type import FileType
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Unset
from typing import cast
from typing import cast, List
from typing import cast, Union
from typing import Dict
from typing import Union
from uuid import UUID



def _get_kwargs(
    project_id: str,
    location_id: UUID,
    *,
    file_type: Union[FileType, None, Unset] = UNSET,

) -> Dict[str, Any]:
    

    

    params: Dict[str, Any] = {}

    json_file_type: Union[None, Unset, str]
    if isinstance(file_type, Unset):
        json_file_type = UNSET
    elif isinstance(file_type, FileType):
        json_file_type = file_type.value
    else:
        json_file_type = file_type
    params["file_type"] = json_file_type


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_id}/locations/{location_id}/files".format(project_id=project_id,location_id=location_id,),
        "params": params,
    }


    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[HTTPValidationError, List['File']]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in (_response_200):
            response_200_item = File.from_dict(response_200_item_data)



            response_200.append(response_200_item)

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())



        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[HTTPValidationError, List['File']]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,

) -> Response[Union[HTTPValidationError, List['File']]]:
    """ Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, List['File']]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
location_id=location_id,
file_type=file_type,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,

) -> Optional[Union[HTTPValidationError, List['File']]]:
    """ Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, List['File']]
     """


    return sync_detailed(
        project_id=project_id,
location_id=location_id,
client=client,
file_type=file_type,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,

) -> Response[Union[HTTPValidationError, List['File']]]:
    """ Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, List['File']]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
location_id=location_id,
file_type=file_type,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,

) -> Optional[Union[HTTPValidationError, List['File']]]:
    """ Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, List['File']]
     """


    return (await asyncio_detailed(
        project_id=project_id,
location_id=location_id,
client=client,
file_type=file_type,

    )).parsed

==> field_manager_python_client-4.4.90rc6.tar.gz: field_manager_python_client-4.4.90rc6/field-manager-python-client/api/locations/get_files_in_location_in_project_projects_project_id_locations_location_id_files_get.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.file import File
from ...models.file_type import FileType
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: str,
    location_id: UUID,
    *,
    file_type: Union[FileType, None, Unset] = UNSET,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    json_file_type: Union[None, Unset, str]
    if isinstance(file_type, Unset):
        json_file_type = UNSET
    elif isinstance(file_type, FileType):
        json_file_type = file_type.value
    else:
        json_file_type = file_type
    params["file_type"] = json_file_type

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": f"/projects/{project_id}/locations/{location_id}/files",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, List["File"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = File.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, List["File"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,
) -> Response[Union[HTTPValidationError, List["File"]]]:
    """Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, List['File']]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        location_id=location_id,
        file_type=file_type,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,
) -> Optional[Union[HTTPValidationError, List["File"]]]:
    """Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, List['File']]
    """

    return sync_detailed(
        project_id=project_id,
        location_id=location_id,
        client=client,
        file_type=file_type,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,
) -> Response[Union[HTTPValidationError, List["File"]]]:
    """Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, List['File']]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        location_id=location_id,
        file_type=file_type,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    location_id: UUID,
    *,
    client: AuthenticatedClient,
    file_type: Union[FileType, None, Unset] = UNSET,
) -> Optional[Union[HTTPValidationError, List["File"]]]:
    """Get Files In Location In Project

     Return database file objects for a specific location and optional file type

    Args:
        project_id (str):
        location_id (UUID):
        file_type (Union[FileType, None, Unset]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, List['File']]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            location_id=location_id,
            client=client,
            file_type=file_type,
        )
    ).parsed
